Serializer
----------


Serializer
==========
.. automodule:: gordo_components.serializer.serializer
    :members:
    :undoc-members:
    :show-inheritance:

Pipeline from definition
========================
.. automodule:: gordo_components.serializer.pipeline_from_definition
    :members:
    :undoc-members:
    :show-inheritance:

Pipeline into definition
========================
.. automodule:: gordo_components.serializer.pipeline_into_definition
    :members:
    :undoc-members:
    :show-inheritance:
